@@ -181,7 +181,6 @@ def plot_strain(get_waveform, dets, fixed_params, tgps, params = None, whiten_fl
         detector = dets[d]
         ax = fig.add_subplot(nsub_panels,1,i+1)
         if whiten_flag:
-            warnings.warn("This is an illustrative plot using the FD PSD and a default windowing, it does not correspond to the full TD treatment applied in the analysis.")
             timeseries = whiten(detector.time_series, detector.psd, dt, kwargs['f-min-bp'], kwargs['f-max-bp'], mf_time_prior)
             max_heigth = timeseries.max()
             wtleg      = 'whitened'
@@ -366,6 +365,7 @@ def f0_t0_gr(samples, qnm_interpolants, Mf_s, af_s, Num_mode, **kwargs):
         Num_modes += len(n_values)*(2*l+1)
     sys.stdout.write(('Total number of modes used to produce plots: {0}\n'.format(Num_modes)))
     colors_manual= [ 'green', 'forestgreen', 'mediumaquamarine', 'springgreen', 'aquamarine', 'khaki', 'yellow','gold', 'orange', 'orangered', 'red', 'firebrick']
+
     i = 0
     theoretical_values = []
     labels = []
@@ -1120,13 +1120,13 @@ def read_Mf_af_IMR_posterior(Config, **input_par):
             PYRING_PREFIX    = set_prefix(warning_message=False)
             custom_datapath  = os.path.join(PYRING_PREFIX, file)
             if(os.path.exists(package_datapath)):
-                print('Fetching the posterior from the default ones included in the package.')
+                print('\nFetching the posterior from the default ones included in the package.\n')
                 file = package_datapath
             elif(os.path.exists(custom_datapath)):
-                print('Fetching the posterior relatively to the PYRING_PREFIX.')
+                print('\nFetching the posterior relatively to the PYRING_PREFIX.\n')
                 file = custom_datapath
             else:
-                print('Fetching the posterior using the provided absolute path.')
+                print('\nFetching the posterior using the provided absolute path.\n')
                 pass
             Mf_d = np.genfromtxt(file, names=True)['Mf']
             af_d = np.genfromtxt(file, names=True)['af']
