@@ -13,7 +13,7 @@ import lal
 try:
     import surfinBH
 except:
-    warnings.warn("Import of surfinBH failed with error {}.".format(traceback.print_exc()))
+    warnings.warn("surfinBH is not automatically installed due to possible conflicts. If you wish to use its functionalities, it needs to be installed separately.")
 
 
 
@@ -434,6 +434,7 @@ def F_mrg_Nagar(m1, m2, a1, a2):
     num         = 1.+((b1+c1*X12)/(1.+c2*X12))*Shat+b2*Shat**2
     denom       = 1.+((b3+c3*X12)/(1.+c4*X12))*Shat
     res         = (orb*num/denom)*((2*np.pi*M)*lal.G_SI*lal.C_SI**(-3))**(-1)
+    
     return res
 
 def F_mrg_Bohe(m1,m2,a1,a2):
